<?php
/**
 * Handle the main admin welcome screen
 * 
 * @package WorldCup
 * @version $Id: wcp-overview.class.php 928636 2014-06-08 20:31:09Z landoweb $
 * @author landoweb
 * @copyright Copyright Landoweb Programador, 2014
 * 
 */
 
class WorldCupOverview extends WorldCupAdmin {
	
	function dashboard() {
		
		global $wpdb;
		$disabled = '';
		
		$teams    = intval( $wpdb->get_var("SELECT COUNT(*) FROM {$wpdb->prefix}{$this->prefix}team WHERE country <> 'xxx'") );
		$venues = intval( $wpdb->get_var("SELECT COUNT(*) FROM {$wpdb->prefix}{$this->prefix}venue") );
		$matches    = intval( $wpdb->get_var("SELECT COUNT(*) FROM {$wpdb->prefix}{$this->prefix}match") );
		$predictions = intval( $wpdb->get_var("SELECT COUNT(*) FROM {$wpdb->prefix}{$this->prefix}prediction") );
		
		if ($teams || $venues || $matches) {
			$disabled = ' disabled ';
		}
		
		?>
		
		<p class="sub"><?php _e('At a Glance', WCP_TD); ?></p>
		<div class="table">
			<table>
				<tbody>
					<tr class="first">
						<td class="first b"><?php echo $teams; ?></td>
						<td class="t"><?php echo _n( 'Team', 'Teams', $teams, WCP_TD ); ?></td>
					</tr>
					<tr class="first">
						<td class="first b"><?php echo $venues; ?></td>
						<td class="t"><?php echo _n( 'Venue', 'Venues', $venues, WCP_TD ); ?></td>
					</tr>
					<tr class="first">
						<td class="first b"><?php echo $matches; ?></td>
						<td class="t"><?php echo _n( 'Match', 'Matches', $matches, WCP_TD ); ?></td>
					</tr>
					<tr class="first">
						<td class="first b"><?php echo $predictions; ?></td>
						<td class="t"><?php echo _n( 'Prediction', 'Predictions', $predictions, WCP_TD ); ?></td>
					</tr>
				</tbody>
			</table>
		</div>
		<div class="versions">
			<?php _e('Here you can import your teams, venues and match schedules.', WCP_TD) ?>
			<?php if(current_user_can($this->prefix . 'manager')): ?>
				<form method="POST">
				<p class="submit">
					<input <?php echo $disabled; ?> type="submit" name="<?php echo $this->prefix; ?>import" class="button rbutton" value="<?php _e('Import', WCP_TD) ?>" />
				</p>
				</form>
			<?php endif; ?>
			<p>
			<?php
				$userlevel = '<span class="b">' . (current_user_can($this->prefix . 'manager') ? __('World Cup Manager', WCP_TD) : __('no', WCP_TD)) . '</span>';
		        printf(__('You currently have %s rights.', WCP_TD), $userlevel);
		    ?>
		    </p>
		</div>
		<?php
	}
	
	function news() {
			// get feed_messages
			require_once(ABSPATH . WPINC . '/feed.php');
		?>
		<div class="rss-widget">
			    <?php
			$feed_url = 'http://www.wcp.net.br/feed/';
			$feed = @fetch_feed($feed_url);
			if ($feed && !isset($feed->errors)) {
				?><ul><?php 
				foreach ($feed->get_items(0, $feed->get_item_quantity(5)) as $item) {
			        ?>
			          <li><a class="rsswidget" title="" href='<?php echo wp_filter_kses($item->get_permalink()); ?>'><?php echo esc_html($item->get_title()); ?></a>
					  <span class="rss-date"><?php echo $item->get_date(); ?></span> 
			          <div class="rssSummary"><?php echo $item->get_description(); ?></div></li>
			        <?php
				}
				?></ul><?php 
			} else {
				echo '<p>' . sprintf(__('Newsfeed could not be loaded.  Check the <a href="%s">front page</a> to check for updates.', WCP_TD), 'http://www.wcp.net.br/') . '</p>';
			}
		    ?>
		</div>
		<?php
	}
	
	function donators() {
		$i = 0;
		$list = '';
		
		$supporter = $this->get_remote_array('http://www.wcp.net.br/donations.php');
		
		// Ensure that this is a array
		if ( !is_array($supporter) )
			return _e('Thank you to all donators...', WCP_TD);
			
		$supporter = array_reverse($supporter);
		
		foreach ($supporter as $name => $url) {
			$i++;
			if ($url)
				$list .= "<li><a href=\"$url\">$name</a></li>\n";
			else
				$list .= "<li>$name</li>";
			if ($i > 6)
				break;
		}
		?>
		<div id="dashboard_server_settings" class="dashboard-widget-holder">
			<div class="wcp-dashboard-widget">
			  	<div class="dashboard-widget-content">
			  		<ul class="wcup-settings">
					<?php echo $list; ?>
					</ul>
					<p class="textright" style="margin-right:10px">
						<a href="http://www.wcp.net.br/donate/" title="<?php _e('Donate', WCP_TD); ?>"><img alt="<?php _e('Donate', WCP_TD); ?>" src="https://www.paypal.com/en_US/i/btn/btn_donate_LG.gif" /></a>
					</p>
				</div>
		    </div>
		</div>
		<?php	
	}
	
	function get_server_info() {
		global $wpdb;
		
		// Get MYSQL Version
		$sqlversion = $wpdb->get_var("SELECT VERSION() AS version");
		// GET SQL Mode
		$mysqlinfo = $wpdb->get_results("SHOW VARIABLES LIKE 'sql_mode'");
		if (is_array($mysqlinfo)) $sql_mode = $mysqlinfo[0]->Value;
		if (empty($sql_mode)) $sql_mode = __('Not set', WCP_TD);
		// Get PHP Safe Mode
		if(ini_get('safe_mode')) $safe_mode = __('On', WCP_TD);
		else $safe_mode = __('Off', WCP_TD);
		
	?>
		<li><?php _e('Operating System', WCP_TD); ?> : <span><?php echo PHP_OS; ?></span></li>
		<li><?php _e('Server', WCP_TD); ?> : <span><?php echo $_SERVER["SERVER_SOFTWARE"]; ?></span></li>
		<li><?php _e('MYSQL Version', WCP_TD); ?> : <span><?php echo $sqlversion; ?></span></li>
		<li><?php _e('SQL Mode', WCP_TD); ?> : <span><?php echo $sql_mode; ?></span></li>
		<li><?php _e('PHP Version', WCP_TD); ?> : <span><?php echo PHP_VERSION; ?></span></li>
		<li><?php _e('PHP Safe Mode', WCP_TD); ?> : <span><?php echo $safe_mode; ?></span></li>
	<?php
	}
	
	function server() {
		?>
		<div id="dashboard_server_settings" class="dashboard-widget-holder wp_dashboard_empty">
			<div class="wcp-dashboard-widget">
			  	<div class="dashboard-widget-content">
		      		<ul class="wcup-settings">
		      		<?php $this->get_server_info(); ?>
			   		</ul>
				</div>
		    </div>
		</div>
		<?php	
	}
	
	function support() {
		?>
		<div id="dashboard_server_settings" class="dashboard-widget-holder wp_dashboard_empty">
			<div class="wcp-dashboard-widget">
			  	<div class="dashboard-widget-content">
			  		<a href="http://wordpress.org/support/plugin/world-cup-predictor"><?php _e('Support Forum', WCP_TD); ?></a>
				</div>
		    </div>			
		</div>
		<?php	
	}
	
	function overview() {
		
		add_meta_box('dashboard_right_now', __('Welcome to World Cup Predictor V ', WCP_TD) . self::VERSION, array(&$this, 'dashboard'), 'wcp_overview', 'left', 'core');
		add_meta_box('dashboard_primary', __('Latest News', WCP_TD), array(&$this, 'news'), 'wcp_overview', 'right', 'core');
		add_meta_box('wcp_donators', __('Recent donators', WCP_TD), array(&$this, 'donators'), 'wcp_overview', 'right', 'core');
		add_meta_box('wcp_server', __('Server Settings', WCP_TD), array(&$this, 'server'), 'wcp_overview', 'right', 'core');
		add_meta_box('wcp_settings', __('Settings', WCP_TD), array(&$this, 'settings'), 'wcp_overview', 'left', 'core');
		add_meta_box('wcp_support', __('Support', WCP_TD), array(&$this, 'support'), 'wcp_overview', 'left', 'core');
		
		if (isset($_POST[$this->prefix.'import'])) {
			$this->import();
		}
	?>
	<div class="wrap wcp-wrap">
		<h2><?php _e('World Cup Predictor Overview', WCP_TD) ?></h2>
		<div id="dashboard-widgets-wrap" class="wcp-overview">
		    <div id="dashboard-widgets" class="metabox-holder">
				<div id="post-body">
					<div id="dashboard-widgets-main-content">
						<div class="postbox-container" style="width:49%;">
							<?php do_meta_boxes('wcp_overview', 'left', ''); ?>
						</div>
			    		<div class="postbox-container" style="width:49%;">
							<?php do_meta_boxes('wcp_overview', 'right', ''); ?>
						</div>						
					</div>
				</div>
		    </div>
		</div>
	</div>
	<script type="text/javascript">
		//<![CDATA[
		jQuery(document).ready( function($) {
			// postboxes setup
			postboxes.add_postbox_toggles('wcc-overview');
		});
		//]]>
	</script>
	<?php
		
	}
	
	/**
	 * Read an array from a remote url
	 * 
	 * @param string $url
	 * @return array of the content
	 */
	function get_remote_array($url) {
		if ( function_exists('wp_remote_request') ) {
			
			$options = array();
			$options['headers'] = array(
				'User-Agent' => 'World Cup Predictor V' . self::VERSION . '; (' . get_bloginfo('url') .')'
			);
			
			$response = wp_remote_request($url, $options);
			
			if ( is_wp_error( $response ) )
				return false;
			
			if ( 200 != $response['response']['code'] )
				return false;
		   	
			$content = unserialize($response['body']);
			
			if (is_array($content)) 
				return $content;
		}
		
		return false;	
	}
	
	function import() {
		
		global $wpdb;
		
		$sql = "INSERT INTO `{$wpdb->prefix}{$this->prefix}match` (`match_id`, `match_no`, `kickoff`, `home_team_id`, `away_team_id`, `home_goals`, `away_goals`, `home_penalties`, `away_penalties`, `venue_id`, `is_result`, `extra_time`, `stage_id`, `scored`, `wwhen`) VALUES
		(1, 1, '2014-06-12 20:00:00', 6, 12, 0, 0, 0, 0, 12, 0, 0, 1, 0, '2014-01-24 19:49:12'),
		(2, 2, '2014-06-13 16:00:00', 24, 7, 0, 0, 0, 0, 7, 0, 0, 1, 0, '2014-01-24 17:13:20'),
		(3, 3, '2014-06-13 19:00:00', 29, 25, 0, 0, 0, 0, 11, 0, 0, 2, 0, '2014-01-24 17:14:36'),
		(4, 4, '2014-06-13 22:00:00', 8, 3, 0, 0, 0, 0, 3, 0, 0, 2, 0, '2014-01-24 17:14:49'),
		(5, 5, '2014-06-14 16:00:00', 9, 18, 0, 0, 0, 0, 1, 0, 0, 3, 0, '2014-01-24 17:16:00'),
		(6, 6, '2014-06-15 01:00:00', 11, 22, 0, 0, 0, 0, 9, 0, 0, 3, 0, '2014-01-24 17:17:03'),
		(7, 7, '2014-06-14 19:00:00', 31, 10, 0, 0, 0, 0, 5, 0, 0, 4, 0, '2014-01-24 17:23:41'),
		(8, 8, '2014-06-14 22:00:00', 14, 21, 0, 0, 0, 0, 6, 0, 0, 4, 0, '2014-01-24 17:23:58'),
		(9, 9, '2014-06-15 16:00:00', 30, 13, 0, 0, 0, 0, 2, 0, 0, 5, 0, '2014-01-24 17:25:19'),
		(10, 10, '2014-06-15 19:00:00', 15, 19, 0, 0, 0, 0, 8, 0, 0, 5, 0, '2014-01-24 17:25:33'),
		(11, 11, '2014-06-15 22:00:00', 2, 5, 0, 0, 0, 0, 10, 0, 0, 6, 0, '2014-01-24 17:27:25'),
		(12, 12, '2014-06-16 19:00:00', 20, 26, 0, 0, 0, 0, 4, 0, 0, 6, 0, '2014-01-24 17:27:41'),
		(13, 13, '2014-06-16 16:00:00', 16, 27, 0, 0, 0, 0, 11, 0, 0, 7, 0, '2014-01-24 17:30:14'),
		(14, 14, '2014-06-16 22:00:00', 17, 32, 0, 0, 0, 0, 7, 0, 0, 7, 0, '2014-01-24 17:30:30'),
		(15, 15, '2014-06-17 16:00:00', 4, 1, 0, 0, 0, 0, 1, 0, 0, 8, 0, '2014-01-24 17:32:01'),
		(16, 16, '2014-06-17 22:00:00', 28, 23, 0, 0, 0, 0, 3, 0, 0, 8, 0, '2014-01-24 17:32:21'),
		(17, 17, '2014-06-17 19:00:00', 6, 24, 0, 0, 0, 0, 5, 0, 0, 1, 0, '2014-01-24 17:13:42'),
		(18, 18, '2014-06-18 22:00:00', 7, 12, 0, 0, 0, 0, 6, 0, 0, 1, 0, '2014-01-24 17:13:56'),
		(19, 19, '2014-06-18 19:00:00', 29, 8, 0, 0, 0, 0, 10, 0, 0, 2, 0, '2014-01-24 17:15:02'),
		(20, 20, '2014-06-18 16:00:00', 3, 25, 0, 0, 0, 0, 8, 0, 0, 2, 0, '2014-01-24 17:15:19'),
		(21, 21, '2014-06-19 16:00:00', 9, 11, 0, 0, 0, 0, 2, 0, 0, 3, 0, '2014-01-24 17:17:46'),
		(22, 22, '2014-06-19 22:00:00', 22, 18, 0, 0, 0, 0, 7, 0, 0, 3, 0, '2014-01-24 17:18:02'),
		(23, 23, '2014-06-19 19:00:00', 31, 14, 0, 0, 0, 0, 12, 0, 0, 4, 0, '2014-01-24 17:24:17'),
		(24, 24, '2014-06-20 16:00:00', 21, 10, 0, 0, 0, 0, 9, 0, 0, 4, 0, '2014-01-24 17:24:31'),
		(25, 25, '2014-06-20 19:00:00', 30, 15, 0, 0, 0, 0, 11, 0, 0, 5, 0, '2014-01-24 17:25:50'),
		(26, 26, '2014-06-20 22:00:00', 19, 13, 0, 0, 0, 0, 4, 0, 0, 5, 0, '2014-01-24 17:26:33'),
		(27, 27, '2014-06-21 16:00:00', 2, 20, 0, 0, 0, 0, 1, 0, 0, 6, 0, '2014-01-24 17:27:59'),
		(28, 28, '2014-06-21 22:00:00', 26, 5, 0, 0, 0, 0, 3, 0, 0, 6, 0, '2014-01-24 17:28:38'),
		(29, 29, '2014-06-21 19:00:00', 16, 17, 0, 0, 0, 0, 5, 0, 0, 7, 0, '2014-01-24 17:30:46'),
		(30, 30, '2014-06-22 22:00:00', 32, 27, 0, 0, 0, 0, 6, 0, 0, 7, 0, '2014-01-24 17:31:04'),
		(31, 31, '2014-06-22 16:00:00', 4, 28, 0, 0, 0, 0, 10, 0, 0, 8, 0, '2014-01-24 17:32:39'),
		(32, 32, '2014-06-22 19:00:00', 23, 1, 0, 0, 0, 0, 8, 0, 0, 8, 0, '2014-01-24 17:32:57'),
		(33, 33, '2014-06-23 20:00:00', 7, 6, 0, 0, 0, 0, 2, 0, 0, 1, 0, '2014-01-24 17:14:09'),
		(34, 34, '2014-06-23 20:00:00', 12, 24, 0, 0, 0, 0, 9, 0, 0, 1, 0, '2014-01-24 17:14:20'),
		(35, 35, '2014-06-23 16:00:00', 3, 29, 0, 0, 0, 0, 4, 0, 0, 2, 0, '2014-01-24 17:15:31'),
		(36, 36, '2014-06-23 16:00:00', 25, 8, 0, 0, 0, 0, 12, 0, 0, 2, 0, '2014-01-24 17:15:43'),
		(37, 37, '2014-06-24 20:00:00', 22, 9, 0, 0, 0, 0, 3, 0, 0, 3, 0, '2014-01-24 17:18:19'),
		(38, 38, '2014-06-24 20:00:00', 18, 11, 0, 0, 0, 0, 5, 0, 0, 3, 0, '2014-01-24 17:18:33'),
		(39, 39, '2014-06-24 16:00:00', 21, 31, 0, 0, 0, 0, 7, 0, 0, 4, 0, '2014-01-24 17:24:45'),
		(40, 40, '2014-06-24 16:00:00', 10, 14, 0, 0, 0, 0, 1, 0, 0, 4, 0, '2014-01-24 17:25:05'),
		(41, 41, '2014-06-25 20:00:00', 19, 30, 0, 0, 0, 0, 6, 0, 0, 5, 0, '2014-01-24 17:26:54'),
		(42, 42, '2014-06-25 20:00:00', 13, 15, 0, 0, 0, 0, 10, 0, 0, 5, 0, '2014-01-24 17:27:08'),
		(43, 43, '2014-06-25 16:00:00', 26, 2, 0, 0, 0, 0, 8, 0, 0, 6, 0, '2014-01-24 17:29:02'),
		(44, 44, '2014-06-25 16:00:00', 5, 20, 0, 0, 0, 0, 11, 0, 0, 6, 0, '2014-01-24 17:29:50'),
		(45, 45, '2014-06-26 16:00:00', 32, 16, 0, 0, 0, 0, 9, 0, 0, 7, 0, '2014-01-24 17:31:28'),
		(46, 46, '2014-06-26 16:00:00', 27, 17, 0, 0, 0, 0, 2, 0, 0, 7, 0, '2014-01-24 17:31:44'),
		(47, 47, '2014-06-26 20:00:00', 23, 4, 0, 0, 0, 0, 12, 0, 0, 8, 0, '2014-01-24 17:33:36'),
		(48, 48, '2014-06-26 20:00:00', 1, 28, 0, 0, 0, 0, 4, 0, 0, 8, 0, '2014-01-24 17:33:52'),
		(49, 49, '2014-06-28 16:00:00', 33, 42, 0, 0, 0, 0, 1, 0, 0, 9, 0, '2014-01-24 19:48:49'),
		(50, 50, '2014-06-28 20:00:00', 35, 44, 0, 0, 0, 0, 10, 0, 0, 9, 0, '2014-01-24 17:34:33'),
		(51, 51, '2014-06-29 16:00:00', 34, 41, 0, 0, 0, 0, 5, 0, 0, 9, 0, '2014-01-24 17:34:49'),
		(52, 52, '2014-06-29 20:00:00', 36, 43, 0, 0, 0, 0, 9, 0, 0, 9, 0, '2014-01-24 17:35:20'),
		(53, 53, '2014-06-30 16:00:00', 37, 46, 0, 0, 0, 0, 2, 0, 0, 9, 0, '2014-01-24 17:35:34'),
		(54, 54, '2014-06-30 20:00:00', 39, 48, 0, 0, 0, 0, 8, 0, 0, 9, 0, '2014-01-24 17:36:19'),
		(55, 55, '2014-07-01 16:00:00', 38, 45, 0, 0, 0, 0, 12, 0, 0, 9, 0, '2014-01-24 17:37:06'),
		(56, 56, '2014-07-01 20:00:00', 40, 47, 0, 0, 0, 0, 11, 0, 0, 9, 0, '2014-01-24 17:38:27'),
		(57, 57, '2014-07-04 20:00:00', 49, 50, 0, 0, 0, 0, 5, 0, 0, 10, 0, '2014-01-24 17:38:41'),
		(58, 58, '2014-07-04 16:00:00', 53, 54, 0, 0, 0, 0, 10, 0, 0, 10, 0, '2014-01-24 17:38:54'),
		(59, 59, '2014-07-05 20:00:00', 51, 52, 0, 0, 0, 0, 11, 0, 0, 10, 0, '2014-01-24 17:39:34'),
		(60, 60, '2014-07-05 16:00:00', 55, 56, 0, 0, 0, 0, 2, 0, 0, 10, 0, '2014-01-24 17:39:49'),
		(61, 61, '2014-07-08 20:00:00', 57, 58, 0, 0, 0, 0, 1, 0, 0, 11, 0, '2014-01-24 17:40:02'),
		(62, 62, '2014-07-09 20:00:00', 59, 60, 0, 0, 0, 0, 12, 0, 0, 11, 0, '2014-01-24 17:40:16'),
		(63, 63, '2014-07-12 20:00:00', 61, 62, 0, 0, 0, 0, 2, 0, 0, 12, 0, '2014-01-24 17:40:30'),
		(64, 64, '2014-07-13 19:00:00', 63, 64, 0, 0, 0, 0, 10, 0, 0, 13, 0, '2014-01-24 17:40:42')";
		$wpdb->query($sql);
		
		$sql = "INSERT INTO `{$wpdb->prefix}{$this->prefix}stage` (`stage_id`, `stage_name`, `is_group`, `sort_order`, `wwhen`) VALUES
		(1, 'Group A', 1, 1, '2014-01-17 04:03:57'),
		(2, 'Group B', 1, 2, '2014-01-17 04:04:06'),
		(3, 'Group C', 1, 3, '2014-01-17 04:04:15'),
		(4, 'Group D', 1, 4, '2014-01-17 04:04:24'),
		(5, 'Group E', 1, 5, '2014-01-17 04:04:33'),
		(6, 'Group F', 1, 6, '2014-01-17 04:04:44'),
		(7, 'Group G', 1, 7, '2014-01-17 04:05:07'),
		(8, 'Group H', 1, 8, '2014-01-17 04:05:22'),
		(9, 'Round of 16', 0, 9, '2014-01-17 04:05:34'),
		(10, 'Quarter-finals', 0, 10, '2014-01-17 04:05:46'),
		(11, 'Semi-finals', 0, 11, '2014-01-17 04:05:58'),
		(12, 'Play-off for Third Place', 0, 12, '2014-01-17 04:07:01'),
		(13, 'Final', 0, 13, '2014-01-17 04:07:17')";
		$wpdb->query($sql);
		
		$sql = "INSERT INTO `{$wpdb->prefix}{$this->prefix}team` (`team_id`, `name`, `country`, `team_url`, `group_order`, `wwhen`) VALUES
		(1, 'Algeria', 'alg', 'http://www.fifa.com/worldcup/teams/team=43843/index.html', 2, '2014-01-24 17:02:07'),
		(2, 'Argentina', 'arg', 'http://www.fifa.com/worldcup/teams/team=43922/index.html', 1, '2014-01-24 17:03:25'),
		(3, 'Australia', 'aus', 'http://www.fifa.com/worldcup/teams/team=43976/index.html', 4, '2014-01-24 17:04:41'),
		(4, 'Belgium', 'bel', 'http://www.fifa.com/worldcup/teams/team=43935/index.html', 1, '2014-01-24 17:02:24'),
		(5, 'Bosnia-Herzegovina', 'bih', 'http://www.fifa.com/worldcup/teams/team=44037/index.html', 2, '2014-01-24 17:03:43'),
		(6, 'Brazil', 'bra', 'http://www.fifa.com/worldcup/teams/team=43924/index.html', 1, '2014-01-24 16:49:31'),
		(7, 'Cameroon', 'cmr', 'http://www.fifa.com/worldcup/teams/team=43849/index.html', 4, '2014-01-24 17:05:54'),
		(8, 'Chile', 'chi', 'http://www.fifa.com/worldcup/teams/team=43925/index.html', 3, '2014-01-24 17:04:58'),
		(9, 'Colombia', 'col', 'http://www.fifa.com/worldcup/teams/team=43926/index.html', 1, '2014-01-24 17:06:36'),
		(10, 'Costa Rica', 'crc', 'http://www.fifa.com/worldcup/teams/team=43901/index.html', 2, '2014-01-24 17:08:08'),
		(11, 'Côte d\\&#039;Ivoire', 'civ', 'http://www.fifa.com/worldcup/teams/team=43854/index.html', 3, '2014-01-24 17:07:37'),
		(12, 'Croatia', 'cro', 'http://www.fifa.com/worldcup/teams/team=43938/index.html', 2, '2014-01-24 16:49:52'),
		(13, 'Ecuador', 'ecu', 'http://www.fifa.com/worldcup/teams/team=43927/index.html', 2, '2014-01-24 17:09:48'),
		(14, 'England', 'eng', 'http://www.fifa.com/worldcup/teams/team=43942/index.html', 3, '2014-01-24 17:09:08'),
		(15, 'France', 'fra', 'http://www.fifa.com/worldcup/teams/team=43946/index.html', 3, '2014-01-24 17:10:22'),
		(16, 'Germany', 'ger', 'http://www.fifa.com/worldcup/teams/team=43948/index.html', 1, '2014-01-24 17:11:07'),
		(17, 'Ghana', 'gha', 'http://www.fifa.com/worldcup/teams/team=43860/index.html', 3, '2014-01-24 17:11:42'),
		(18, 'Greece', 'gre', 'http://www.fifa.com/worldcup/teams/team=43949/index.html', 2, '2014-01-24 17:06:52'),
		(19, 'Honduras', 'hnd', 'http://www.fifa.com/worldcup/teams/team=43909/index.html', 4, '2014-01-24 17:10:44'),
		(20, 'Iran', 'irn', 'http://www.fifa.com/worldcup/teams/team=43817/index.html', 3, '2014-01-24 17:04:19'),
		(21, 'Italy', 'ita', 'http://www.fifa.com/worldcup/teams/team=43954/index.html', 4, '2014-01-24 17:09:27'),
		(22, 'Japan', 'jpn', 'http://www.fifa.com/worldcup/teams/team=43819/index.html', 4, '2014-01-24 17:07:19'),
		(23, 'Korea Republic', 'kor', 'http://www.fifa.com/worldcup/teams/team=43822/index.html', 4, '2014-01-24 17:03:04'),
		(24, 'Mexico', 'mex', 'http://www.fifa.com/worldcup/teams/team=43911/index.html', 3, '2014-01-24 17:06:13'),
		(25, 'Netherlands', 'ned', 'http://www.fifa.com/worldcup/teams/team=43960/index.html', 2, '2014-01-24 17:05:36'),
		(26, 'Nigeria', 'nga', 'http://www.fifa.com/worldcup/teams/team=43876/index.html', 4, '2014-01-24 17:04:00'),
		(27, 'Portugal', 'por', 'http://www.fifa.com/worldcup/teams/team=43963/index.html', 2, '2014-01-24 17:11:23'),
		(28, 'Russia', 'rus', 'http://www.fifa.com/worldcup/teams/team=43965/index.html', 3, '2014-01-24 17:02:43'),
		(29, 'Spain', 'esp', 'http://www.fifa.com/worldcup/teams/team=43969/index.html', 1, '2014-01-24 17:05:17'),
		(30, 'Switzerland', 'sui', 'http://www.fifa.com/worldcup/teams/team=43971/index.html', 1, '2014-01-24 17:10:04'),
		(31, 'Uruguay', 'uru', 'http://www.fifa.com/worldcup/teams/team=43930/index.html', 1, '2014-01-24 17:08:50'),
		(32, 'USA', 'usa', 'http://www.fifa.com/worldcup/teams/team=43921/index.html', 4, '2014-01-24 17:12:02'),
		(33, 'Winner Group A', 'xxx', '', 0, '2014-01-17 02:20:59'),
		(34, 'Winner Group B', 'xxx', '', 0, '2014-01-17 02:31:37'),
		(35, 'Winner Group C', 'xxx', '', 0, '2014-01-17 02:31:53'),
		(36, 'Winner Group D', 'xxx', '', 0, '2014-01-17 02:32:11'),
		(37, 'Winner Group E', 'xxx', '', 0, '2014-01-17 02:32:25'),
		(38, 'Winner Group F', 'xxx', '', 0, '2014-01-17 02:32:49'),
		(39, 'Winner Group G', 'xxx', '', 0, '2014-01-17 02:33:06'),
		(40, 'Winner Group H', 'xxx', '', 0, '2014-01-17 02:33:23'),
		(41, 'Second Group A', 'xxx', '', 0, '2014-01-17 02:33:47'),
		(42, 'Second Group B', 'xxx', '', 0, '2014-01-17 02:34:03'),
		(43, 'Second Group C', 'xxx', '', 0, '2014-01-17 02:23:36'),
		(44, 'Second Group D', 'xxx', '', 0, '2014-01-17 02:23:49'),
		(45, 'Second Group E', 'xxx', '', 0, '2014-01-17 02:24:00'),
		(46, 'Second Group F', 'xxx', '', 0, '2014-01-17 02:24:14'),
		(47, 'Second Group G', 'xxx', '', 0, '2014-01-17 02:24:29'),
		(48, 'Second Group H', 'xxx', '', 0, '2014-01-17 02:24:42'),
		(49, 'Winner Match 49', 'xxx', '', 0, '2014-01-17 02:24:58'),
		(50, 'Winner Match 50', 'xxx', '', 0, '2014-01-17 02:25:09'),
		(51, 'Winner Match 51', 'xxx', '', 0, '2014-01-17 02:25:21'),
		(52, 'Winner Match 52', 'xxx', '', 0, '2014-01-17 02:25:38'),
		(53, 'Winner Match 53', 'xxx', '', 0, '2014-01-17 02:25:49'),
		(54, 'Winner Match 54', 'xxx', '', 0, '2014-01-17 02:26:07'),
		(55, 'Winner Match 55', 'xxx', '', 0, '2014-01-17 02:26:27'),
		(56, 'Winner Match 56', 'xxx', '', 0, '2014-01-17 02:26:36'),
		(57, 'Winner Match 57', 'xxx', '', 0, '2014-01-17 02:26:48'),
		(58, 'Winner Match 58', 'xxx', '', 0, '2014-01-17 02:26:58'),
		(59, 'Winner Match 59', 'xxx', '', 0, '2014-01-17 02:27:09'),
		(60, 'Winner Match 60', 'xxx', '', 0, '2014-01-17 02:27:19'),
		(61, 'Loser Match 61', 'xxx', '', 0, '2014-01-17 04:09:37'),
		(62, 'Loser Match 62', 'xxx', '', 0, '2014-01-17 04:09:49'),
		(63, 'Winner Match 61', 'xxx', '', 0, '2014-01-17 04:10:15'),
		(64, 'Winner Match 62', 'xxx', '', 0, '2014-01-17 04:10:29')";
		$wpdb->query($sql);
		
		$sql = "INSERT INTO `{$wpdb->prefix}{$this->prefix}venue` (`venue_id`, `venue_name`, `venue_url`, `stadium`, `tz_offset`, `wwhen`) VALUES
		(1, 'Belo Horizonte', 'http://www.fifa.com/worldcup/destination/cities/city=6783/profile.html', 'Estadio Mineirao', -3, '2014-01-24 16:57:07'),
		(2, 'Brasilia', 'http://www.fifa.com/worldcup/destination/cities/city=1143/profile.html', 'Estadio Nacional', -3, '2014-01-24 16:57:28'),
		(3, 'Cuiaba', 'http://www.fifa.com/worldcup/destination/cities/city=50053/profile.html', 'Arena Pantanal', -4, '2014-01-24 16:57:46'),
		(4, 'Curitiba', 'http://www.fifa.com/worldcup/destination/cities/city=35400/profile.html', 'Arena da Baixada', -3, '2014-01-24 16:58:11'),
		(5, 'Fortaleza', 'http://www.fifa.com/worldcup/destination/cities/city=11693/profile.html', 'Estadio Castelao', -3, '2014-01-24 16:59:22'),
		(6, 'Manaus', 'http://www.fifa.com/worldcup/destination/cities/city=2037/profile.html', 'Arena Amazonia', -4, '2014-01-24 16:59:42'),
		(7, 'Natal', 'http://www.fifa.com/worldcup/destination/cities/city=21518/profile.html', 'Estadio das Dunas', -3, '2014-01-24 17:00:02'),
		(8, 'Porto Alegre', 'http://www.fifa.com/worldcup/destination/cities/city=1140/profile.html', 'Estadio Beira-Rio', -3, '2014-01-24 17:00:25'),
		(9, 'Recife', 'http://www.fifa.com/worldcup/destination/cities/city=6099/profile.html', 'Arena Pernambuco', -3, '2014-01-24 17:00:51'),
		(10, 'Rio de Janeiro', 'http://www.fifa.com/worldcup/destination/cities/city=1141/profile.html', 'Estadio do Maracana', -3, '2014-01-24 17:01:10'),
		(11, 'Salvador', 'http://www.fifa.com/worldcup/destination/cities/city=50071/profile.html', 'Arena Fonte Nova', -3, '2014-01-24 17:01:35'),
		(12, 'Sao Paulo', 'http://www.fifa.com/worldcup/destination/cities/city=1047/profile.html', 'Arena de Sao Paulo', -3, '2014-01-24 16:56:27')";
		$wpdb->query($sql);
		
		$this->setMessage(__('Match data imported', WCP_TD));
		$this->printMessage();
	}
}
